/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */

/*
 * EggNetworkTree GTK+ Widget - egg-network-tree-test.c
 * 
 * Copyright (C) 2009 Luca Cavalli <luca.cavalli@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Authors: Luca Cavalli <luca.cavalli@gmail.com>
 */

#include <gtk/gtk.h>

#include "egg-network-tree.h"

void
host_selected_cb (EggNetworkTree *network_tree, gchar *uri, GtkWidget *label)
{
	gchar *text;

	if (uri)
		text = g_markup_printf_escaped ("Host: <i>%s</i>", uri);
	else
		text = g_strdup ("Host: <i>unknown</i>");

	gtk_label_set_markup (GTK_LABEL (label), text);

	g_free (text);
}

void
refresh_btn_clicked_cb (GtkButton *button, EggNetworkTree *network_tree)
{
	egg_network_tree_refresh (network_tree);
}

int
main (int argc, char *argv[])
{
    GtkWidget *window;
	GtkWidget *vbox;
	GtkWidget *scroll;
	GtkWidget *label;
	GtkWidget *hbtnbox;
	GtkWidget *refresh_btn;
    GtkWidget *network_tree;

    gtk_init (&argc, &argv);

    window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
	gtk_window_set_icon_name (GTK_WINDOW (window), "network-workgroup");
	gtk_window_set_default_size (GTK_WINDOW (window), 400, 300);
	gtk_container_set_border_width (GTK_CONTAINER (window), 12);

	vbox = gtk_vbox_new (FALSE, 12);

    gtk_container_add (GTK_CONTAINER (window), vbox);

	scroll = gtk_scrolled_window_new (NULL, NULL);
	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
									GTK_POLICY_AUTOMATIC,
									GTK_POLICY_AUTOMATIC);

    network_tree = egg_network_tree_new ();
	gtk_container_add (GTK_CONTAINER (scroll), network_tree);

	label = gtk_label_new ("Host: <i>unknown</i>");
	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);

	hbtnbox = gtk_hbutton_box_new ();
	gtk_button_box_set_layout (GTK_BUTTON_BOX (hbtnbox), GTK_BUTTONBOX_END);

	refresh_btn = gtk_button_new_from_stock (GTK_STOCK_REFRESH);
	gtk_box_pack_end (GTK_BOX (hbtnbox), refresh_btn, FALSE, TRUE, 12);

	gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, TRUE, 0);
	gtk_box_pack_start (GTK_BOX (vbox), hbtnbox, FALSE, TRUE, 0);

	g_signal_connect (G_OBJECT (network_tree), "host-selected",
					  G_CALLBACK (host_selected_cb), label);

	g_signal_connect (G_OBJECT (window), "destroy",
					  G_CALLBACK (gtk_main_quit), NULL);

	g_signal_connect (G_OBJECT (refresh_btn), "clicked",
					  G_CALLBACK (refresh_btn_clicked_cb), network_tree);

    gtk_widget_show_all (window);

    gtk_main ();

	return 0;
}
